# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`samba`](#samba): This module manages Samba/CIFS, the virtual filesystem based on SMB protocol.
* [`samba::client`](#samba--client): @summary: This module installs the SAMBA/CIFS client. samba::client
* [`samba::config`](#samba--config): @summary: Creates the [global] config section in smb.conf file.
* [`samba::firewall`](#samba--firewall): @summary: Manage the firewall
* [`samba::install`](#samba--install): samba::install
* [`samba::service`](#samba--service): samba::service

### Defined types

* [`samba::option`](#samba--option): Manages smb.conf options.
* [`samba::share`](#samba--share): == Define samba::share

### Data types

* [`Samba::InstallType`](#Samba--InstallType)
* [`Samba::PackageState`](#Samba--PackageState)

## Classes

### <a name="samba"></a>`samba`

For all main options, see the smb.conf(5) and samba(7) man pages.  Default values for all
parameters can be found at https://www.samba.org/samba/docs/current/man-html/smb.conf.5.html.
For the SELinux related options, see smbd_selinux(8).

Sample Usage :
 include samba

#### Parameters

The following parameters are available in the `samba` class:

* [`packages`](#-samba--packages)
* [`package_manage`](#-samba--package_manage)
* [`package_ensure`](#-samba--package_ensure)
* [`config_file`](#-samba--config_file)
* [`config_lens`](#-samba--config_lens)
* [`service_enable`](#-samba--service_enable)
* [`service_ensure`](#-samba--service_ensure)
* [`service_manage`](#-samba--service_manage)
* [`service_name`](#-samba--service_name)
* [`service_ports`](#-samba--service_ports)
* [`firewall_manage`](#-samba--firewall_manage)
* [`workgroup`](#-samba--workgroup)
* [`server_string`](#-samba--server_string)
* [`netbios_name`](#-samba--netbios_name)
* [`domain_master`](#-samba--domain_master)
* [`preferred_master`](#-samba--preferred_master)
* [`local_master`](#-samba--local_master)
* [`os_level`](#-samba--os_level)
* [`wins_support`](#-samba--wins_support)
* [`wins_server`](#-samba--wins_server)
* [`name_resolve_order`](#-samba--name_resolve_order)
* [`server_min_protocol`](#-samba--server_min_protocol)
* [`client_max_protocol`](#-samba--client_max_protocol)
* [`client_min_protocol`](#-samba--client_min_protocol)
* [`hosts_allow`](#-samba--hosts_allow)
* [`hosts_deny`](#-samba--hosts_deny)
* [`interfaces`](#-samba--interfaces)
* [`bind_interfaces_only`](#-samba--bind_interfaces_only)
* [`log_file`](#-samba--log_file)
* [`max_log_size`](#-samba--max_log_size)
* [`passdb_backend`](#-samba--passdb_backend)
* [`domain_logons`](#-samba--domain_logons)
* [`map_to_guest`](#-samba--map_to_guest)
* [`security`](#-samba--security)
* [`encrypt_passwords`](#-samba--encrypt_passwords)
* [`unix_password_sync`](#-samba--unix_password_sync)
* [`socket_options`](#-samba--socket_options)
* [`syslog`](#-samba--syslog)
* [`ntlm_auth`](#-samba--ntlm_auth)
* [`machine_password_timeout`](#-samba--machine_password_timeout)
* [`realm`](#-samba--realm)
* [`kerberos_method`](#-samba--kerberos_method)
* [`dedicated_keytab_file`](#-samba--dedicated_keytab_file)
* [`obey_pam_restrictions`](#-samba--obey_pam_restrictions)
* [`shares`](#-samba--shares)
* [`idmap_config`](#-samba--idmap_config)

##### <a name="-samba--packages"></a>`packages`

Data type:

```puppet
Struct[{
      server => Array[String[1]],
      client => Array[String[1]],
      utils  => Array[String[1]],
  }]
```

Names of the server, client and utility pacakges to be installed when managing Samba.

##### <a name="-samba--package_manage"></a>`package_manage`

Data type: `Boolean`

Should this module manage the installation/removal of the $packages?

##### <a name="-samba--package_ensure"></a>`package_ensure`

Data type: `Samba::PackageState`

The installation state of $packages.

##### <a name="-samba--config_file"></a>`config_file`

Data type: `String`

The Augeas lens to use for managing the smb.conf file.

##### <a name="-samba--config_lens"></a>`config_lens`

Data type: `String`

The Augeas lens to use for managing the smb.conf file.

##### <a name="-samba--service_enable"></a>`service_enable`

Data type: `Variant[Enum[mask, manual], Boolean]`

Enable/disable the Samba service on reboot.

##### <a name="-samba--service_ensure"></a>`service_ensure`

Data type: `Enum[stopped, running]`

The value of ``ensure`` for package resources.

##### <a name="-samba--service_manage"></a>`service_manage`

Data type: `Boolean`

Should the Samba service be managd by this module?

##### <a name="-samba--service_name"></a>`service_name`

Data type: `Array[String]`

The name of the Samba service.

##### <a name="-samba--service_ports"></a>`service_ports`

Data type:

```puppet
Array[
    Struct[
      {
        port  => Integer[0, 65535],
        proto => Enum[tcp, udp],
      }
    ]
  ]
```

The service ports to be added to the firewall (if managed).

##### <a name="-samba--firewall_manage"></a>`firewall_manage`

Data type: `Boolean`

Manage the firewall rules for the Samba services.

##### <a name="-samba--workgroup"></a>`workgroup`

Data type: `Optional[String]`

This controls what workgroup your server will appear to be in when queried by clients.

##### <a name="-samba--server_string"></a>`server_string`

Data type: `Optional[String]`

This controls what string will show up in the printer comment box in print manager and next to the IPC connection in net view.

##### <a name="-samba--netbios_name"></a>`netbios_name`

Data type: `Optional[String]`

This sets the NetBIOS name by which a Samba server is known.

##### <a name="-samba--domain_master"></a>`domain_master`

Data type: `Optional[Boolean]`

Tell smbd(8) to enable WAN-wide browse list collation.

##### <a name="-samba--preferred_master"></a>`preferred_master`

Data type: `Optional[Boolean]`

This boolean parameter controls if nmbd(8) is a preferred master browser for its workgroup.

##### <a name="-samba--local_master"></a>`local_master`

Data type: `Optional[Boolean]`

This option allows nmbd(8) to try and become a local master browser on a subnet.

##### <a name="-samba--os_level"></a>`os_level`

Data type: `Optional[Integer[0, 255]]`

This integer value controls what level Samba advertises itself as for browse elections.

##### <a name="-samba--wins_support"></a>`wins_support`

Data type: `Optional[Boolean]`

This boolean controls if the nmbd(8) process in Samba will act as a WINS server.

##### <a name="-samba--wins_server"></a>`wins_server`

Data type: `Optional[String]`

This specifies the IP address (or DNS name: IP address for preference) of the WINS server that nmbd(8) should register with.

##### <a name="-samba--name_resolve_order"></a>`name_resolve_order`

Data type: `Optional[String]`

This option is used by the programs in the Samba suite to determine what naming services to use and in what order to resolve host names to IP addresses.

##### <a name="-samba--server_min_protocol"></a>`server_min_protocol`

Data type: `Optional[String]`

This setting controls the minimum protocol version that the server will allow the client to use.

##### <a name="-samba--client_max_protocol"></a>`client_max_protocol`

Data type: `Optional[String]`

The value of the parameter (a string) is the highest protocol level that will be supported for IPC$ connections as DCERPC transport.

##### <a name="-samba--client_min_protocol"></a>`client_min_protocol`

Data type: `Optional[String]`

This setting controls the minimum protocol version that the client will attempt to use.

##### <a name="-samba--hosts_allow"></a>`hosts_allow`

Data type: `Array[String]`

This parameter is a comma, space, or tab delimited set of hosts which are permitted to access a service.

##### <a name="-samba--hosts_deny"></a>`hosts_deny`

Data type: `Array[String]`

The opposite of hosts allow - hosts listed here are NOT permitted access to services unless the specific services have their own lists to override this one.

##### <a name="-samba--interfaces"></a>`interfaces`

Data type: `Array[String]`

default: interfaces =

##### <a name="-samba--bind_interfaces_only"></a>`bind_interfaces_only`

Data type: `Optional[Boolean]`

This global parameter allows the Samba admin to limit what interfaces on a machine will serve SMB requests.

##### <a name="-samba--log_file"></a>`log_file`

Data type: `Optional[String]`

This option allows you to override the name of the Samba log file (also known as the debug file).

##### <a name="-samba--max_log_size"></a>`max_log_size`

Data type: `Optional[Integer]`

This option (an integer in kilobytes) specifies the max size the log file should grow to.

##### <a name="-samba--passdb_backend"></a>`passdb_backend`

Data type: `Optional[String]`

This option allows the administrator to chose which backend will be used for storing user and possibly group information.

##### <a name="-samba--domain_logons"></a>`domain_logons`

Data type: `Optional[Boolean]`

DEPRECATED:  This parameter has been deprecated since Samba 4.13 and support for NT4-style domain logons(as distinct from the Samba AD DC) will be removed in a future Samba release.

##### <a name="-samba--map_to_guest"></a>`map_to_guest`

Data type: `Optional[String]`

This parameter can take four different values, which tell smbd(8) what to do with user login requests that don't match a valid UNIX user in some way.

##### <a name="-samba--security"></a>`security`

Data type: `Optional[String]`

This option affects how clients respond to Samba.

##### <a name="-samba--encrypt_passwords"></a>`encrypt_passwords`

Data type: `Optional[Boolean]`

DEPRECATED: This boolean controls whether encrypted passwords will be negotiated with the client

##### <a name="-samba--unix_password_sync"></a>`unix_password_sync`

Data type: `Optional[Boolean]`

This boolean parameter controls whether Samba attempts to synchronize the UNIX password with the SMB password when the encrypted SMB password in the smbpasswd file is changed.

##### <a name="-samba--socket_options"></a>`socket_options`

Data type: `Optional[String]`

This option allows you to set socket options to be used when talking with the client.

##### <a name="-samba--syslog"></a>`syslog`

Data type: `Optional[String]`

This parameter maps how Samba debug messages are logged onto the system syslog logging levels.

##### <a name="-samba--ntlm_auth"></a>`ntlm_auth`

Data type: `Variant[Enum['ntlmv1-permitted', 'ntlmv2-only', 'mschapv2-and-ntlmv2-only', 'disabled'], Boolean]`

This parameter determines whether or not smbd(8) will attempt to authenticate users using the NTLM encrypted password response for this local passdb (SAM or account database).

##### <a name="-samba--machine_password_timeout"></a>`machine_password_timeout`

Data type: `Optional[Integer]`

This parameter specifies how often the MACHINE ACCOUNT password will be changed, in seconds.

##### <a name="-samba--realm"></a>`realm`

Data type: `Optional[String]`

This option specifies the kerberos realm to use.

##### <a name="-samba--kerberos_method"></a>`kerberos_method`

Data type: `Optional[String]`

Controls how kerberos tickets are verified.

##### <a name="-samba--dedicated_keytab_file"></a>`dedicated_keytab_file`

Data type: `Optional[String]`

Specifies the absolute path to the kerberos keytab file when kerberos method is set to "dedicated keytab".

##### <a name="-samba--obey_pam_restrictions"></a>`obey_pam_restrictions`

Data type: `Optional[Boolean]`

This parameter will control whether or not Samba should obey PAM's account and session management directives.

##### <a name="-samba--shares"></a>`shares`

Data type: `Hash`

A hash of share names, their path(s) and other parameters.

Default value: `{}`

##### <a name="-samba--idmap_config"></a>`idmap_config`

Data type: `Optional[Hash]`

The mapping between Windows SIDs and Unix user and group IDs.

### <a name="samba--client"></a>`samba::client`

@summary: This module installs the SAMBA/CIFS client.
samba::client

#### Parameters

The following parameters are available in the `samba::client` class:

* [`packages`](#-samba--client--packages)
* [`package_manage`](#-samba--client--package_manage)
* [`package_ensure`](#-samba--client--package_ensure)

##### <a name="-samba--client--packages"></a>`packages`

Data type:

```puppet
Struct[{
      server => Array[String[1]],
      client => Array[String[1]],
      utils  => Array[String[1]],
  }]
```

The name of the Samba client package.

Default value: `$samba::packages`

##### <a name="-samba--client--package_manage"></a>`package_manage`

Data type: `Boolean`

Should the Samba client package be managed by this module?

Default value: `$samba::package_manage`

##### <a name="-samba--client--package_ensure"></a>`package_ensure`

Data type: `Samba::PackageState`

The installation state of the Samba client package

Default value: `$samba::package_ensure`

### <a name="samba--config"></a>`samba::config`

@summary: Creates the [global] config section in smb.conf file.

### <a name="samba--firewall"></a>`samba::firewall`

@summary: Manage the firewall

### <a name="samba--install"></a>`samba::install`

samba::install

### <a name="samba--service"></a>`samba::service`

samba::service

## Defined types

### <a name="samba--option"></a>`samba::option`

Manages smb.conf options.

#### Parameters

The following parameters are available in the `samba::option` defined type:

* [`key`](#-samba--option--key)
* [`value`](#-samba--option--value)
* [`config_file`](#-samba--option--config_file)
* [`lens`](#-samba--option--lens)
* [`target`](#-samba--option--target)

##### <a name="-samba--option--key"></a>`key`

Data type: `String`

This is the Samba configuration parameter to be set.

Default value: `$title`

##### <a name="-samba--option--value"></a>`value`

Data type: `Variant[Boolean, Integer, String, Array[String], Undef]`

The value of $key in the smb.conf file.

Default value: `undef`

##### <a name="-samba--option--config_file"></a>`config_file`

Data type: `String`

The path to the Samba configuration file. eg: /etc/samba/smb.conf.

Default value: `$samba::config_file`

##### <a name="-samba--option--lens"></a>`lens`

Data type: `String`

The Augeas lens used to manage the entries in the $config_file.

Default value: `$samba::config_lens`

##### <a name="-samba--option--target"></a>`target`

Data type: `String`

The Augeas target for the key/value pair settings.

Default value: `$samba::target`

### <a name="samba--share"></a>`samba::share`

== Define samba::share

#### Parameters

The following parameters are available in the `samba::share` defined type:

* [`comment`](#-samba--share--comment)
* [`path`](#-samba--share--path)
* [`writable`](#-samba--share--writable)
* [`available`](#-samba--share--available)
* [`browseable`](#-samba--share--browseable)
* [`copy`](#-samba--share--copy)
* [`create_mask`](#-samba--share--create_mask)
* [`directory_mask`](#-samba--share--directory_mask)
* [`force_create_mode`](#-samba--share--force_create_mode)
* [`force_directory_mode`](#-samba--share--force_directory_mode)
* [`force_group`](#-samba--share--force_group)
* [`force_user`](#-samba--share--force_user)
* [`guest_account`](#-samba--share--guest_account)
* [`guest_ok`](#-samba--share--guest_ok)
* [`guest_only`](#-samba--share--guest_only)
* [`hide_unreadable`](#-samba--share--hide_unreadable)
* [`inherit_owner`](#-samba--share--inherit_owner)
* [`inherit_permissions`](#-samba--share--inherit_permissions)
* [`read_only`](#-samba--share--read_only)
* [`public`](#-samba--share--public)
* [`printable`](#-samba--share--printable)
* [`valid_users`](#-samba--share--valid_users)
* [`follow_symlinks`](#-samba--share--follow_symlinks)
* [`wide_links`](#-samba--share--wide_links)
* [`map_acl_inherit`](#-samba--share--map_acl_inherit)
* [`store_dos_attributes`](#-samba--share--store_dos_attributes)
* [`strict_allocate`](#-samba--share--strict_allocate)
* [`oplocks`](#-samba--share--oplocks)
* [`level2_oplocks`](#-samba--share--level2_oplocks)
* [`veto_oplock_files`](#-samba--share--veto_oplock_files)
* [`write_list`](#-samba--share--write_list)
* [`ensure`](#-samba--share--ensure)

##### <a name="-samba--share--comment"></a>`comment`

Data type: `Optional[String]`

This is a text field that is seen next to a share when a client does a queries the server, either via the network neighborhood or via net view to list what shares are available.

Default value: `undef`

##### <a name="-samba--share--path"></a>`path`

Data type: `Optional[Stdlib::Absolutepath]`

This parameter specifies a directory to which the user of the service is to be given access.

Default value: `undef`

##### <a name="-samba--share--writable"></a>`writable`

Data type: `Optional[Boolean]`

If this parameter is true (ie: yes) then users of a service may create or modify files in the service's directory.

Default value: `undef`

##### <a name="-samba--share--available"></a>`available`

Data type: `Optional[Boolean]`

This parameter lets you "turn off" a service. If available = false (ie, no), then ALL attempts to connect to the service will fail.

Default value: `undef`

##### <a name="-samba--share--browseable"></a>`browseable`

Data type: `Optional[Boolean]`

This controls whether this share is seen in the list of available shares in a net view and in the browse list.

Default value: `undef`

##### <a name="-samba--share--copy"></a>`copy`

Data type: `Optional[String]`

This parameter allows you to "clone" service entries. The specified service is simply duplicated under the current service's name.

Default value: `undef`

##### <a name="-samba--share--create_mask"></a>`create_mask`

Data type: `Optional[String]`

This parameter is a bit-wise MASK for the UNIX modes of a file.

Default value: `undef`

##### <a name="-samba--share--directory_mask"></a>`directory_mask`

Data type: `Optional[String]`

This parameter is the octal modes which are used when converting DOS modes to UNIX modes when creating UNIX directories.

Default value: `undef`

##### <a name="-samba--share--force_create_mode"></a>`force_create_mode`

Data type: `Optional[String]`

This parameter specifies a set of UNIX mode bit permissions that will always be set on a file created by Samba.

Default value: `undef`

##### <a name="-samba--share--force_directory_mode"></a>`force_directory_mode`

Data type: `Optional[String]`

This parameter specifies a set of UNIX mode bit permissions that will always be set on a directory created by Samba.

Default value: `undef`

##### <a name="-samba--share--force_group"></a>`force_group`

Data type: `Optional[String]`

This specifies a UNIX group name that will be assigned as the default primary group for all users connecting to this service.

Default value: `undef`

##### <a name="-samba--share--force_user"></a>`force_user`

Data type: `Optional[String]`

This specifies a UNIX user name that will be assigned as the default user for all users connecting to this service.

Default value: `undef`

##### <a name="-samba--share--guest_account"></a>`guest_account`

Data type: `Optional[String]`

This is a username which will be used for access to services which are specified as $guest_ok (see below).

Default value: `undef`

##### <a name="-samba--share--guest_ok"></a>`guest_ok`

Data type: `Optional[Boolean]`

If this parameter is true (ie: yes) for a service, then no password is required to connect to the service.

Default value: `undef`

##### <a name="-samba--share--guest_only"></a>`guest_only`

Data type: `Optional[Boolean]`

If this parameter is true (ie: yes) for a service, then only guest connections to the service are permitted

Default value: `undef`

##### <a name="-samba--share--hide_unreadable"></a>`hide_unreadable`

Data type: `Optional[Boolean]`

This parameter prevents clients from seeing the existence of files that cannot be read.

Default value: `undef`

##### <a name="-samba--share--inherit_owner"></a>`inherit_owner`

Data type: `Optional[Boolean]`

The ownership of new files and directories is normally governed by effective uid of the connected user.

Default value: `undef`

##### <a name="-samba--share--inherit_permissions"></a>`inherit_permissions`

Data type: `Optional[Boolean]`

The permissions on new files and directories are normally governed by create mask, directory mask, force create mode and force directory mode

Default value: `undef`

##### <a name="-samba--share--read_only"></a>`read_only`

Data type: `Optional[Boolean]`

If this parameter is true (ie: yes) then users of a service may not create or modify files in the service's directory.

Default value: `undef`

##### <a name="-samba--share--public"></a>`public`

Data type: `Optional[Boolean]`

If this parameter is true (ie: yes) for a service, then no password is required to connect to the service.

Default value: `undef`

##### <a name="-samba--share--printable"></a>`printable`

Data type: `Optional[Boolean]`

If this parameter is true (ie: yes) then clients may open, write to and submit spool files on the directory specified for the service.

Default value: `undef`

##### <a name="-samba--share--valid_users"></a>`valid_users`

Data type: `Optional[Array[String]]`

This is a list of users that should be allowed to login to this service.

Default value: `undef`

##### <a name="-samba--share--follow_symlinks"></a>`follow_symlinks`

Data type: `Optional[Boolean]`

This parameter allows the Samba administrator to stop smbd(8) from following symbolic links in a particular share.

Default value: `undef`

##### <a name="-samba--share--wide_links"></a>`wide_links`

Data type: `Optional[Boolean]`

This parameter controls whether or not links in the UNIX file system may be followed by the server

Default value: `undef`

##### <a name="-samba--share--map_acl_inherit"></a>`map_acl_inherit`

Data type: `Optional[Boolean]`

this parameter controls whether smbd(8) will attempt to map the 'protected' (don't inherit) flags of the Windows ACLs into an extended attribute called user.SAMBA_PAI (POSIX draft ACL Inheritance).

Default value: `undef`

##### <a name="-samba--share--store_dos_attributes"></a>`store_dos_attributes`

Data type: `Optional[Boolean]`

When set, DOS attributes will be stored onto an extended attribute in the UNIX filesystem, associated with the file or directory.

Default value: `undef`

##### <a name="-samba--share--strict_allocate"></a>`strict_allocate`

Data type: `Optional[Boolean]`

When this is set to yes the server will change from UNIX behaviour of not committing real disk storage blocks when a file is extended to the Windows behaviour of actually forcing the disk system to allocate real storage blocks when a file is created or extended to be a given size. In UNIX terminology this means that Samba will stop creating sparse files.

Default value: `undef`

##### <a name="-samba--share--oplocks"></a>`oplocks`

Data type: `Optional[String]`

This boolean option tells smbd whether to issue oplocks (opportunistic locks) to file open requests on this share.

Default value: `undef`

##### <a name="-samba--share--level2_oplocks"></a>`level2_oplocks`

Data type: `Optional[String]`

This parameter controls whether Samba supports level2 (read-only) oplocks on a share.

Default value: `undef`

##### <a name="-samba--share--veto_oplock_files"></a>`veto_oplock_files`

Data type: `Optional[String]`

This parameter allows the Samba administrator to selectively turn off the granting of oplocks on selected files that match a wildcarded list, similar to the wildcarded list used in the veto files parameter.

Default value: `undef`

##### <a name="-samba--share--write_list"></a>`write_list`

Data type: `Optional[String]`

This is a list of users that are given read-write access to a service.

Default value: `undef`

##### <a name="-samba--share--ensure"></a>`ensure`

Data type: `Enum[present, absent]`

The absent/present state of the key/value parameter.

Default value: `present`

## Data types

### <a name="Samba--InstallType"></a>`Samba::InstallType`

The Samba::InstallType data type.

Alias of

```puppet
Struct[{
    ensure => Samba::PackageState,
}]
```

### <a name="Samba--PackageState"></a>`Samba::PackageState`

The Samba::PackageState data type.

Alias of `Enum[present, absent, purged, disabled, installed, latest]`

